@@ -75,7 +75,7 @@ class PytificationsMessageWithPhoto:
             "password_hash":hashlib.sha256(Pytifications._password.encode('utf-8')).hexdigest(),
             "message_id":self._message_id,
             "buttons":requestedButtons,
-            "script_id":Pytifications._script_id
+            "process_id":Pytifications._process_id
         }
 
         if photo != None:
@@ -136,7 +136,7 @@ class PytificationsMessage:
             "password_hash":hashlib.sha256(Pytifications._password.encode('utf-8')).hexdigest(),
             "message_id":self._message_id,
             "buttons":requestedButtons,
-            "script_id":Pytifications._script_id
+            "process_id":Pytifications._process_id
         }
 
         
@@ -165,7 +165,7 @@ class Pytifications:
     _loop = None
     _registered_callbacks = {}
     _last_message_id = 0
-    _script_id = 0
+    _process_id = 0
     
    
     def login(login:str,password:str) -> bool:
@@ -188,8 +188,8 @@ class Pytifications:
             res = requests.post('https://pytifications.herokuapp.com/initialize_script',json={
                 "username":login,
                 "password_hash":hashlib.sha256(password.encode('utf-8')).hexdigest(),
-                "script_name":sys.argv[0],
-                "script_language":'python'
+                "process_name":sys.argv[0],
+                "process_language":'python'
             })
         except Exception as e:
             print(f'Found exception while logging in: {e}')
@@ -202,8 +202,8 @@ class Pytifications:
             return False
         else:
             Pytifications._logged_in = True
-            Pytifications._script_id = res.text
-            print(f'success logging in to pytifications! script id = {Pytifications._script_id}')
+            Pytifications._process_id = res.text
+            print(f'success logging in to pytifications! script id = {Pytifications._process_id}')
 
         Thread(target=Pytifications._check_if_any_callbacks_to_be_called,daemon=True).start()
         
@@ -220,7 +220,7 @@ class Pytifications:
                 res = requests.get('https://pytifications.herokuapp.com/get_callbacks',json={
                     "username":Pytifications._login,
                     "password_hash":hashlib.sha256(Pytifications._password.encode('utf-8')).hexdigest(),
-                    "script_id":Pytifications._script_id
+                    "process_id":Pytifications._process_id
                 })
             except Exception as e:
                 print(e)
@@ -269,7 +269,7 @@ class Pytifications:
                 "password_hash":hashlib.sha256(Pytifications._password.encode('utf-8')).hexdigest(),
                 "message":message,
                 "buttons":requestedButtons,
-                "script_id":Pytifications._script_id
+                "process_id":Pytifications._process_id
         }
 
         if photo != None:
@@ -329,7 +329,7 @@ class Pytifications:
             "password_hash":hashlib.sha256(Pytifications._password.encode('utf-8')).hexdigest(),
             "message_id":Pytifications._last_message_id,
             "buttons":requestedButtons,
-            "script_id":Pytifications._script_id
+            "process_id":Pytifications._process_id
         }
 
         
